#
# spec file for package html2ps
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           html2ps
Version:        1.0b7
Release:        1.2
URL:            http://user.it.uu.se/~jan/html2ps.html
Summary:        HTML to PostScript Converter
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/HTML/Tools
Source0:        http://user.it.uu.se/~jan/%name-%version.tar.gz
Source1:        html2psrc
Patch0:         %{name}-1.0b5-open.diff
Patch1:         %{name}-1.0b5-opt.diff
Patch2:         document_dsc_option.patch
Patch3:         remove_latin1_char.patch
Patch4:         xhtml2ps_defaults.patch
Patch5:         default_paper_size.patch
Patch6:         proper_variable_escaping.patch
Patch7:         shell_tricks_removed.patch
Patch8:         large_eps_fix.patch
Patch9:         DSC_to_dsc.patch
Patch10:        fix_ps.patch
Patch11:        checker_warning.patch
Patch12:        upstream_changelog.patch
Patch13:        perl-deprecations.patch
Patch14:        html2ps-1.0b7-tmpname.patch
BuildRequires:  ImageMagick
BuildRequires:  ghostscript-fonts-std
BuildRequires:  ghostscript-x11
BuildRequires:  jpeg
BuildRequires:  netpbm
BuildRequires:  perl-libwww-perl
BuildRequires:  texlive-latex
Requires:       ImageMagick
Requires:       ghostscript_any
Requires:       gv
Requires:       netpbm
Requires:       perl
Requires:       perl-libwww-perl
BuildArch:      noarch

%description
An HTML to PostScript converter written in Perl.  Html2ps understands
many of the HTML 4.0 features.	From the home page
(http://www.tdb.uu.se/~jan/html2ps.html):

* Many ways to control the appearance; this is mostly done using
   configuration files.
* Support for processing multiple documents, can be done
   automatically by recursively following links.
* A table of contents can be generated, either from the links in a
   document or automatically from document headings.
* Configurable page headers and footers that can, for example,
   contain document title, URL, page number, current heading, and
   date.
* Automatic hyphenation and text justification can be selected.

%prep
%autosetup -p1

%build

%install
install -d -m755 %{buildroot}/%{_bindir}/
install -d -m755 %{buildroot}/%{_sysconfdir}/
install -d -m755 %{buildroot}/%{_prefix}/lib/html2ps/
install -d -m755 %{buildroot}/%{_mandir}/man{1,5}/
install -m755 html2ps %{buildroot}/%{_bindir}/
install -m755 contrib/xhtml2ps/xhtml2ps %{buildroot}/%{_bindir}/
install -m644 %{S:1} %{buildroot}/%{_sysconfdir}/
install -m644 hyphen.tex %{buildroot}/%{_prefix}/lib/html2ps/
install -m644 html2ps.1 %{buildroot}/%{_mandir}/man1/
install -m644 html2psrc.5 %{buildroot}/%{_mandir}/man5/

%files
%defattr(-, root, root)
%license COPYING
%doc README html2ps.html
%config %{_sysconfdir}/html2psrc
%doc %{_mandir}/man?/*
%{_bindir}/html2ps
%{_bindir}/xhtml2ps
%{_prefix}/lib/html2ps/

%changelog
* Thu Nov 14 2024 Dr. Werner Fink <werner@suse.de>
- Add patch html2ps-1.0b7-tmpname.patch
  * Close the race between tmpnam() and sysopen
* Tue Nov 12 2024 Dr. Werner Fink <werner@suse.de>
- Modify patch xhtml2ps_defaults.patch as we have no "see"
  ... use "gv -media=a4 -scale -2"
* Tue Nov 12 2024 Dr. Werner Fink <werner@suse.de>
- Update ot 1.0b7
  * Fixed a bug introduced by the previous bug fix...
  * 1.0b6
    "Security" fix. Changed behavior for SSI, to avoid having
    arbitrary readable files disclosed on a web server that uses
    html2ps in a web application (cgi script etc), allowing HTML
    files to be uploaded for conversion. Setting up a service like
    this is begging for trouble in my opinion. (Is /bin/cat also
    a vulnerability, since one can use it in a web app, allowing
    uploading arbitrary parameters to it?)
- Port patches
  html2ps-1.0b5-open.diff
  html2ps-1.0b5-opt.diff
- Add and port Debian patch set (boo#1214060)
  * document_dsc_option.patch
  * remove_latin1_char.patch
  * xhtml2ps_defaults.patch
  * default_paper_size.patch
  * proper_variable_escaping.patch
  * shell_tricks_removed.patch
  * large_eps_fix.patch
  * DSC_to_dsc.patch
  * fix_ps.patch
  * checker_warning.patch
  * upstream_changelog.patch
  * perl-deprecations.patch
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri May 12 2017 werner@suse.de
- Add patch html2ps-1.0b5-opt.diff
  to fix location of configuration files boo#778426
* Wed Oct 15 2014 jengelh@inai.de
- Use source URLs and remove ancient specfile tags and sections
* Fri Nov 14 2008 mrueckert@suse.de
- Always require ImageMagick. We have it in the BuildRequires
  aswell.
- make package noarch
* Sun Apr 22 2007 ro@suse.de
- use texlive for building
* Fri Oct 20 2006 mjancar@suse.cz
- update to 1.0b5
  * few bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 10 2003 tcrhak@suse.cz
- merged fixes from 8.1, viz.
  - Don't require ImageMagick on SLES
  - fixed insecure open() calls
* Thu Oct 31 2002 tcrhak@suse.cz
- added BuildRoot
* Wed May 22 2002 kukuk@suse.de
- Put xhtml2ps from contrib into doc directory to avoid tcl/tk
  dependencies.
* Fri Feb 15 2002 kukuk@suse.de
- Change old package name in Requires with new one, replace lynx
  with perl-libwww-perl as suggested in documentation.
* Wed Aug  8 2001 adostal@suse.cz
- update to version 2.0.0
- fix install
* Fri Jul 20 2001 kukuk@suse.de
- changed neededforbuild <gs_x11> to <ghostscript-x11>
* Wed Dec 20 2000 lmuelle@suse.de
- Add needed Requires: lynx
- bzip2ed source
* Mon Dec 18 2000 lmuelle@suse.de
- Remove obsolet Requires: lynx2
* Fri Dec 15 2000 pthomas@suse.de
- Make html2ps require lynx2. This allows the user to install
  either lynx or lynxssl.
* Wed Nov  8 2000 ro@suse.de
- fixed neededforbuild for ImageMagick
* Thu Feb 24 2000 freitag@suse.de
- moved manpages to /usr/share/man
* Fri Nov  5 1999 max@suse.de
- changed wish's path to /usr/bin
* Mon Sep 20 1999 ro@suse.de
- added requires ghostscript_any
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Mar  2 1998 ro@suse.de
- fixed dependency for /usr/bin/wish
* Sun Feb 15 1998 ray@suse.de
- bugfix
- include the binary and config file
* Wed Feb 11 1998 ray@suse.de
- new package (v1.0b1)
* Mon Jan 12 1998 ke@suse.de
- initial package: version 1.0 beta1.
